Learn R Programming

plattice (version 1.1)

plattice-package: This is an R package that provides lattice plot for panel data.

Description

It creates a lattice plot to visualize panel or longitudinal data. The observed values are plotted as dots and the fitted values as lines, both against time. The plot is customizable and easy to edit, even if you do not know how to construct a lattice plot from scratch.

Arguments

Author

Michail Tsagris mtsagris@uoc.gr, Christos Adam pada4m4@gmail.com.

Maintainers

Michail Tsagris mtsagris@uoc.gr

Details

Package:plattice
Type:Package
Version:1.1
Date:2024-12-04
License:GPL-2